Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6105)

Unified Diff: chrome_elf/chrome_elf_constants.h

Issue 2760853002: Remove use of PRODUCT_STRING_PATH in chrome_elf. (Closed)
Patch Set: now Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome_elf/blacklist/test/blacklist_test.cc ('k') | chrome_elf/chrome_elf_constants.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome_elf/chrome_elf_constants.h
diff --git a/chrome_elf/chrome_elf_constants.h b/chrome_elf/chrome_elf_constants.h
index 0039b8960d526287125e61edc5007e93d38d36a8..6b234288d8700766bad357fa9de533fa8774ce73 100644
--- a/chrome_elf/chrome_elf_constants.h
+++ b/chrome_elf/chrome_elf_constants.h
@@ -11,8 +11,8 @@
namespace blacklist {
-// The registry path of the blacklist beacon.
-extern const wchar_t kRegistryBeaconPath[];
+// The name of the blacklist beacon registry key.
+extern const wchar_t kRegistryBeaconKeyName[];
// The properties for the blacklist beacon.
extern const wchar_t kBeaconVersion[];
@@ -40,12 +40,10 @@ enum BlacklistState {
namespace elf_sec {
// The registry path of the finch "emergency-off"
// switch for sandbox::MITIGATION_EXTENSION_POINT_DISABLE.
-extern const wchar_t kRegSecurityFinchPath[];
+extern const wchar_t kRegSecurityFinchKeyName[];
-// The registry path for any early-browser security settings.
-extern const wchar_t kRegSecurityPath[];
-}
+} // namespace elf_sec
#endif // CHROME_ELF_CHROME_ELF_CONSTANTS_H_
« no previous file with comments | « chrome_elf/blacklist/test/blacklist_test.cc ('k') | chrome_elf/chrome_elf_constants.cc » ('j') | no next file with comments »
@@ -40,12 +40,10 @@ enum BlacklistState {
namespace elf_sec {
-// The registry path of the finch "emergency-off"
+// The name of the registry key holding the finch "emergency-off"
// switch for sandbox::MITIGATION_EXTENSION_POINT_DISABLE.

Powered by Google App Engine
This is Rietveld 408576698